@@ -22,6 +22,7 @@ from .version import __version__ as version
 
 # setupt default working directory
 _DEFAULT_WD = os.path.join(tempfile.gettempdir(), 'mge_finder')
+DEFAULT_CONFIG = resource_filename(__name__, 'config.ini')
 
 # Options
 SHARED_OPTIONS = [
@@ -114,7 +115,7 @@ def cli(quiet):
               help='Sequencing files in fastq format. Only used for annotating sequence depth in GFF files (Optional)')
 @click.option('--config',
               type=ConfigFileParam(),
-              default=resource_filename(__name__, 'config.ini'),
+              default=DEFAULT_CONFIG,
               help='Path to user defined config')
 @click.option('-j',
               '--json',
@@ -169,10 +170,15 @@ def find(output, config, fq_file, threads, contig, kma_path, min_coverage,
     if not contig:
         raise click.UsageError('No input files')
 
+    # set default config
+    default_cfg = ConfigParser()
+    default_cfg.read(DEFAULT_CONFIG, encoding='utf-8')
+    # create execution context object
     ctx = ExecutionContext(
         fq_files=list(fq_file) if fq_file else fq_file,
         sample_name=_get_fname(fq_file[0]) if fq_file else _get_fname(contig),
         config=config,
+        default_config=default_cfg,
         mge_db=MGEdb(),  # load database object
         base_wd_dir=temp_dir,
         kma_path=kma_path,
