@@ -55,7 +55,7 @@ class ExecutionContext:
     def cnf_get_default(self, func_name: str, *args):
         """Get default configuration from config parser objects."""
         section = args[0]
-        if section not in self.config:
+        if not self.config.has_option(*args):
             cnf = self.default_config
             LOG.warning(f'Section "{section}" not in supplied config file, fallback to default config')
         else:
