@@ -21,27 +21,6 @@ from .tools import BlastHit, BlastHsp, iter_blast_hits
 LOG = logging.getLogger(__name__)
 
 
-def _is_valid_hit(hit: ElementHit, cfg: ConfigParser) -> bool:
-    """Validate good hits."""
-    if hit.tot_aln_cov < cfg.getfloat('validation', 'coverage'):
-        return False
-
-    # combined hsp len is larger than reference seqeunce
-    if (hit.subject_len * 1.05) < hit.element_len:
-        return False
-
-    # if no hit is significant
-    if not any(h.e_value == 0 for h in hit.hsps):
-        evals = (math.log10(h.e_value) for h in hit.hsps)
-        if max(evals) > cfg.getfloat('validation', 'e_value'):
-            return False
-            
-    # if hit.avg_seq_id < cfg.getfloat('validation', 'identity'):
-    #     return False
-
-    return True
-
-
 def _calc_tot_aln_cov(group: HspBin, hit: BlastHit) -> Union[int, float]:
     """Calculate total alignement coverage of group of hsps."""
     tot_len = sum(_hsp_len(hsp) for hsp in group)
